@@ -1,6 +1,6 @@
 =begin
 /****************************************************************************
-** $Id: qt/examples/buttongroups/main.cpp   2.2.2   edited 2000-08-31 $
+** $Id: buttongroups.rb,v 1.1.1.1 2002/12/22 14:19:46 taka-hr Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -11,17 +11,17 @@
 =end
 #include "buttongroups.h"
 #include <qapplication.h>
-require "qt2"
-include Qt2
+require "qte"
+include Qte
+require "qpe"
+include Qpe
 require "buttongroups_lib.rb"
 
-   a = QApplication.new( [$0]+ARGV );
+   a = QPEApplication.new( [$0]+ARGV );
 
     buttonsgroups = ButtonGroups.new;
-    buttonsgroups.resize( 500, 250 );
     buttonsgroups.setCaption( "Examples for Buttons and Groups" );
-    a.setMainWidget( buttonsgroups );
-    buttonsgroups.show();
+    a.showMainWidget( buttonsgroups );
 
     a.exec();
 
