@@ -1,8 +1,8 @@
 #test of data_ptr
 #make unique instance of ruby for c++ pointer
 #and cast c++ pointer to the ruby object
-require "qt2"
-include Qt2
+require "qte"
+include Qte
 
 module CPPPtr
 
