@@ -1,6 +1,6 @@
 =begin
 /****************************************************************************
-** $Id: dclock.rb,v 1.1.1.2 2000/11/14 17:04:55 horie Exp $
+** $Id: dclock.rb,v 1.1.1.1 2002/12/22 14:19:51 taka-hr Exp $
 **
 ** Copyright (C) 1992-2000 Troll Tech AS.  All rights reserved.
 **
@@ -9,14 +9,15 @@
 **
 *****************************************************************************/
 =end
-require "qt2"
-include Qt2
+require "qte"
+include Qte
+require "qpe"
+include Qpe
 require "dclock_lib.rb"
 
-    a = QApplication.new( [$0]+ARGV )
+    a = QPEApplication.new( [$0]+ARGV )
     clock = DigitalClock.new(8)
     clock.resize( 170, 80 )
-    a.setMainWidget( clock )
-    clock.show()
+    a.showMainWidget( clock )
     a.exec()
 
