@@ -1,6 +1,6 @@
 =begin
 /****************************************************************************
-** $Id: application.rb,v 1.1.1.2 2000/11/14 17:04:53 horie Exp $
+** $Id: mdi.rb,v 1.1.1.1 2002/12/22 14:19:53 taka-hr Exp $
 **
 ** Copyright (C) 1992-2000 Troll Tech AS.  All rights reserved.
 **
@@ -9,14 +9,16 @@
 **
 *****************************************************************************/
 =end
-require "qt2"
-include Qt2
+require "qte"
+include Qte
+require "qpe"
+include Qpe
 require "mdi_application_lib.rb"
-    QApplication::setStyle(QCDEStyle.new)
-    a = QApplication.new([$0]+ARGV)
+#    QPEApplication::setStyle(QCDEStyle.new)
+    a = QPEApplication.new([$0]+ARGV)
 #    QApplication::setStyle(QWindowsStyle.new)
     mw = ApplicationWindow.new
     mw.setCaption( QString.new("Multiple Document") )
-    mw.show
+    a.showMainWidget(mw)
     connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") );
     a.exec
