@@ -1,7 +1,9 @@
-require "qt2"
-include Qt2
-require "qt2table"
-include Qt2table
+require "qte"
+include Qte
+require "qpe"
+include Qpe
+require "qtetable"
+include Qtetable
 
 class Table < QTable
 
@@ -34,11 +36,9 @@ end
 
 end
 
-a = QApplication.new([$0]+ARGV)
+a = QPEApplication.new([$0]+ARGV)
 table = Table.new(5,3,nil,"table")
 
-a.setMainWidget(table)
-
-table.show
+a.showMainWidget(table)
 
 a.exec
