@@ -1,6 +1,6 @@
 =begin
 /****************************************************************************
-** $Id: qt/examples/richtext/main.cpp   2.3.0   edited 2001-01-26 $
+** $Id: richtext.rb,v 1.1.1.1 2002/12/22 14:19:55 taka-hr Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -11,16 +11,17 @@
 =end
 #include "richtext.h"
 #include <qapplication.h>
-require "qt2"
-include Qt2
+require "qte"
+include Qte
+require "qpe"
+include Qpe
 require "richtext_lib.rb"
 
-    a = QApplication.new ( [$0]+ARGV )
+    a = QPEApplication.new ( [$0]+ARGV )
 
     richtext = MyRichText.new
     richtext.resize( 450, 350 )
     richtext.setCaption( "Fortune" )
-    a.setMainWidget( richtext )
-    richtext.show()
+    a.showMainWidget( richtext )
 
     a.exec()
