@@ -1,6 +1,6 @@
 =begin
 /****************************************************************************
-** $Id: qt/examples/xmlquotes/main.cpp   2.2.2   edited 2000-08-31 $
+** $Id: xmlquotes.rb,v 1.1.1.1 2002/12/22 14:19:57 taka-hr Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -14,15 +14,17 @@
 #include <qapplication.h>
 #include <qfile.h>
 #include <qmessagebox.h>
-require "qt2"
-include Qt2
-require "qt2xml"
-include Qt2xml
+require "qte"
+include Qte
+require "qpe"
+include Qpe
+require "qtexml"
+include Qtexml
 
 require "richtext.rb"
 require "quoteparser.rb"
 
-    a = QApplication.new( [$0]+ARGV )
+    a = QPEApplication.new( [$0]+ARGV )
 
     #// parse xml file
     handler = QuoteHandler.new
@@ -45,8 +47,7 @@ require "quoteparser.rb"
     richtext.setString( handler.quotes() )
     richtext.resize( 450, 350 )
     richtext.setCaption( "Fortune" )
-    a.setMainWidget( richtext )
-    richtext.show()
+    a.showMainWidget( richtext )
 
     a.exec()
 
