@@ -7,16 +7,17 @@
 ****************************************************************/
 =end
 require "qte"
-include Qt2
+include Qte
+require "qpe"
+include Qpe
 
-    a = QApplication.new( [$0]+ARGV)
+    a = QPEApplication.new( [$0]+ARGV)
 
     quit = QPushButton.new( "Quit", nil )
     quit.resize( 75, 30 );
     quit.setFont( QFont.new( "Times", 18, QFont::Bold ) )
 
-    Qt2::connect( quit, QSIGNAL("clicked()"), a, "quit" )
+    Qte::connect( quit, QSIGNAL("clicked()"), a, "quit" )
 
-    a.setMainWidget( quit )
-    quit.show()
+    a.showMainWidget( quit )
     a.exec()
