@@ -7,9 +7,11 @@
 ****************************************************************/
 =end
 require "qte"
-include Qt2
+include Qte
+require "qpe"
+include Qpe
 
-    a = QApplication.new( [$0]+ARGV )
+    a = QPEApplication.new( [$0]+ARGV )
 
     box = QVBox.new
     box.resize( 200, 120 )
@@ -17,10 +19,9 @@ include Qt2
     quit = QPushButton.new( "Quit", box )
     quit.setFont( QFont.new( "Times", 18, QFont::Bold ) )
 
-    Qt2::connect( quit, QSIGNAL("clicked()"), a,"quit" )
+    Qte::connect( quit, QSIGNAL("clicked()"), a,"quit" )
 
-    a.setMainWidget( box )
-    box.show()
+    a.showMainWidget( box )
 
     a.exec()
 
