@@ -8,7 +8,9 @@
 =end
 
 require "qte"
-include Qt2
+include Qte
+require "qpe"
+include Qpe
 
 class LCDRange  < QVBox
 
@@ -31,7 +33,7 @@ def initialize ( parent=nil, name="" )
     quit = QPushButton.new( "Quit", self, "quit" )
     quit.setFont( QFont.new( "Times", 18, QFont::Bold ) )
 
-    connect( quit, QSIGNAL("clicked()"), QApplication::qApp, "quit()" )
+    connect( quit, QSIGNAL("clicked()"), QPEApplication::qApp, "quit()" )
 
     grid = QGrid.new( 4, self )
 
@@ -43,10 +45,9 @@ def initialize ( parent=nil, name="" )
 end
 end
 
-    a = QApplication.new( [$0]+ARGV )
+    a = QPEApplication.new( [$0]+ARGV )
 
     w = MyWidget.new
-    a.setMainWidget( w )
-    w.show()
+    a.showMainWidget( w )
     a.exec()
 
